"""CLI entry point for python -m attune.cli execution.

Copyright 2025 Smart-AI-Memory
Licensed under Fair Source License 0.9
"""

import sys

from . import main

if __name__ == "__main__":
    sys.exit(main())
