"""Workflow scaffolding module.

Generates workflow code from patterns.

Copyright 2025 Smart-AI-Memory
Licensed under Fair Source License 0.9
"""

from .generator import WorkflowGenerator

__all__ = ["WorkflowGenerator"]
